PKG_PATH="$(dirname "$0")/Lightroom"
LR_PATH="Library/Application Support/Adobe/Lightroom"
MOD_PATH="$LR_PATH/Modules/"
PRESET_PATH="$LR_PATH/Export Presets/"
PRESET_PATH_2="Pictures/Lightroom/Lightroom Settings/Export Presets/"
BIN_PATH="mergeraw.lrplugin/mergeraw-mac64"
PLEASE="Please try the Manual Installation instructions in INSTALL.rtf."
DNG_CONV="/Applications/Adobe DNG Converter.app/Contents/MacOS/Adobe DNG Converter"
ERROR="ERROR:"
VERBOSE=

echo "Checking for Adobe DNG Converter... \c"
[ -x "$DNG_CONV" ] && "$DNG_CONV" 2>/dev/null -c && echo "OK\n" ||
echo "\n$ERROR Unable to locate Adobe DNG Converter. Merge Raw requires Adobe DNG Converter to provide camera-specific information about reading raw files. Please download and install Adobe DNG Converter before running Merge Raw. You man download Adobe DNG Converter Here: http://www.adobe.com/go/dng_converter_mac/ (hold Command and double-click to open link)\n"

if [ -d ~/"$MOD_PATH" ]; then

  echo "Removing any old versions of the plugin... \c"
  rm $VERBOSE -df ~/"$MOD_PATH"/mergeraw.lrplugin/* ~/"$MOD_PATH"/mergeraw.lrplugin
  rm $VERBOSE -df ~/"$MOD_PATH"/rmprof.lrplugin/* ~/"$MOD_PATH"/rmprof.lrplugin
  echo "OK\n"

  echo "Installing Merge Raw Plugin into user Lightroom plugin directory (~/$MOD_PATH)... \c"
  if ! cp $VERBOSE -r $PKG_PATH/mergeraw.lrplugin $PKG_PATH/rmprof.lrplugin ~/"$MOD_PATH"; then
    echo "\n$ERROR Failed copying plugin. $PLEASE"; exit 1
  fi  
  echo "OK\n"

elif [ -d "/$MOD_PATH" ]; then

  echo "Removing old versions of the plugin... \c"
  rm $VERBOSE -df /"$MOD_PATH"/mergeraw.lrplugin/* /"$MOD_PATH"/mergeraw.lrplugin
  rm $VERBOSE -df /"$MOD_PATH"/rmprof.lrplugin/* /"$MOD_PATH"/rmprof.lrplugin
  echo "OK\n"

  echo "Installing Merge Raw Plugin into system-wide Lightroom plugin directory (/$MOD_PATH)... \c"
  if ! cp $VERBOSE -r $PKG_PATH/mergeraw.lrplugin $PKG_PATH/rmprof.lrplugin "/$MOD_PATH"; then
    echo "\n$ERROR Failed copying plugin. $PLEASE"; exit 1
  fi
  echo "OK\n"

elif [ -d ~/"$LR_PATH" ]; then

  echo "Creating Lightroom Plugin directory (~/$MOD_PATH)"

  mkdir -p ~/"$MOD_PATH"

  if [ -d ~/"$MOD_PATH" ]; then

    echo "Installing Merge Raw Plugin into user Lightroom plugin directory (~/$MOD_PATH)... \c"
    if ! cp $VERBOSE -r $PKG_PATH/mergeraw.lrplugin $PKG_PATH/rmprof.lrplugin ~/"$MOD_PATH"; then
      echo "\n$ERROR Failed copying plugin. $PLEASE"; exit 1
    fi  
    echo "OK\n"

  else

    echo "Unable to create Lightroom Plugin directory. $PLEASE"
    exit 1

  fi

elif [ -d /"$LR_PATH" ]; then

  echo "Creating Lightroom Plugin directory (/$MOD_PATH)"

  mkdir -p /"$MOD_PATH"

  if [ -d /"$MOD_PATH" ]; then

    echo "Installing Merge Raw Plugin into system-wide Lightroom plugin directory (/$MOD_PATH)... \c"
    if ! cp $VERBOSE -r $PKG_PATH/mergeraw.lrplugin $PKG_PATH/rmprof.lrplugin "/$MOD_PATH"; then
      echo "\n$ERROR Failed copying plugin. $PLEASE"; exit 1
    fi  
    echo "OK\n"

  else

    echo "Unable to create Lightroom Plugin directory. $PLEASE"
    exit 1

  fi

else

  echo "Unable to identify Lightroom Plugin directory location. $PLEASE"
  exit 1

fi

if [ -d ~/"$PRESET_PATH" ]; then

  echo "Installing Merge Raw Preset into user Export Presets directory (~/$PRESET_PATH)... \c"
  if ! cp $VERBOSE -r "$PKG_PATH/mergeraw.lrpreset/Merge Raw Files" "$PKG_PATH/rmprof.lrpreset/Remove Built-in Profile" ~/"$PRESET_PATH"; then
    echo "\n$ERROR Failed copying preset. $PLEASE"; exit 1
  fi
  echo "OK\n"

fi

if [ -d ~/"$PRESET_PATH_2" ]; then

  echo "Installing Merge Raw Preset into default catalog Export Presets directory (~/$PRESET_PATH_2)... \c"
  if ! cp $VERBOSE -r "$PKG_PATH/mergeraw.lrpreset/Merge Raw Files" "$PKG_PATH/rmprof.lrpreset/Remove Built-in Profile" ~/"$PRESET_PATH_2"; then
    echo "\n$ERROR Failed copying preset. $PLEASE"; exit 1
  fi
  echo "OK\n"

  echo "If you store presets with your catalog and this is not the path to your catalog file, $PLEASE\n"
fi

if [ ! "(" -d ~/"$PRESET_PATH" -o -d ~/"$PRESET_PATH_2" ")" ]; then
  echo "$ERROR Unable to identify Lightroom Export Preset directory location. $PLEASE"; exit 1
fi

if [ -d ~/"$MOD_PATH" ]; then
  ~/"$MOD_PATH"$BIN_PATH -v || echo "$ERROR Unable to run $BIN_PATH. $PLEASE"
elif [ -d "/$MOD_PATH" ]; then
  "/$MOD_PATH"$BIN_PATH -v || echo "$ERROR Unable to run $BIN_PATH. $PLEASE"
fi

echo "\nInstallation appears successful. You may close this window."
